{% extends 'base.html' %}
{% load i18n %}
{% block title %}Log Error{% endblock %}

{% block page_header %}
{% include "horizon/common/_page_header.html" with title=_("Log Error") %}
{% endblock page_header %}

{% block main %}
    <div class="col-sm-12" ng-cloak ng-init="">
        <ng-include src="'{{ STATIC_URL }}dashboard/admin/venus/logError/logError.html'"></ng-include>
    </div>
{% endblock %}
